@@ -9,9 +9,15 @@ public class Client
     {
         try 
 	{
-            // initiliaze the ORB.
+            // initialize the ORB.
             ORB orb = ORB.init( args, null );
 
+            if( args.length == 0 )
+            {
+                System.err.println("usage: jaco Client <ior>");
+                System.exit(1);
+            }
+
             // get object reference from command-line argument
             org.omg.CORBA.Object obj = orb.string_to_object( args[0] );
 
@@ -27,6 +33,9 @@ public class Client
 
             // invoke the operation and print the result
             System.out.println( goodDay.hello() );
+
+            // invoke the operation again and print the wide string result
+            System.out.println( "wide string: " + goodDay.hello_wide() );
         }
         // catch CORBA system exceptions
         catch(SystemException ex) 
