@@ -27,7 +27,7 @@ package jacorb.orb;
  * vice versa<p>
  *
  * @author Gerald Brose, FU Berlin
- * @version $Id: Connection.java,v 1.60 2000/10/24 12:33:58 brose Exp $
+ * @version $Id: Connection.java,v 1.61 2000/11/02 13:21:21 brose Exp $
  *
  */
 
@@ -454,7 +454,7 @@ public class Connection
         return id_count++; /* */
     }
 
-    protected void incUsers()
+    protected synchronized void incUsers()
     {
         client_count++;
     }
